@@ -933,9 +933,13 @@ bonobo_control_frame_sync_realize (BonoboControlFrame *frame)
 	Bonobo_Control_realize (control, &ev);
 
 #ifdef BONOBO_CONTROL_FRAME_DEBUG
-	if (BONOBO_EX (&ev))
-		g_warning ("Exception on realize '%s'",
-			   bonobo_exception_get_text (&ev));
+	if (BONOBO_EX (&ev)) {
+		char *text;
+		
+		text = bonobo_exception_get_text (&ev);
+		g_warning ("Exception on realize '%s'", text);
+		g_free (text);
+	}
 #endif
 
 	CORBA_exception_free (&ev);
@@ -963,9 +967,13 @@ bonobo_control_frame_sync_unrealize (BonoboControlFrame *frame)
 
 	Bonobo_Control_unrealize (control, &ev);
 #ifdef BONOBO_CONTROL_FRAME_DEBUG
-	if (BONOBO_EX (&ev))
-		g_warning ("Exception on unrealize '%s'",
-			   bonobo_exception_get_text (&ev));
+	if (BONOBO_EX (&ev)) {
+		char *text;
+		
+		text = bonobo_exception_get_text (&ev);
+		g_warning ("Exception on unrealize '%s'", text);
+		g_free (text);
+	}
 #endif
 
 	CORBA_exception_free (&ev);
@@ -1035,8 +1043,12 @@ bonobo_control_frame_focus_child (BonoboControlFrame *frame, GtkDirectionType di
 
 	result = Bonobo_Control_focusChild (priv->control, corba_direction, &ev);
 	if (BONOBO_EX (&ev)) {
+		char *text;
+		
+		text = bonobo_exception_get_text (&ev);
 		g_message ("bonobo_control_frame_focus_child(): Exception while issuing focusChild "
-			   "request: `%s'", bonobo_exception_get_text (&ev));
+			   "request: `%s'", text);
+		g_free (text);
 		result = FALSE;
 	}
 
