@@ -284,7 +284,7 @@ bonobo_event_source_init (GtkObject *object)
 	BonoboEventSource *event_source;
 
 	event_source = BONOBO_EVENT_SOURCE (object);
-	event_source->priv = g_new (BonoboEventSourcePrivate, 1);
+	event_source->priv = g_new0 (BonoboEventSourcePrivate, 1);
 	event_source->priv->listeners = NULL;
 }
 
@@ -364,9 +364,14 @@ bonobo_event_source_client_remove_listener (Bonobo_Unknown  object,
  remove_listener_end:
 
 	if (!opt_ev) {
-		if (BONOBO_EX (my_ev))
-			g_warning ("remove_listener failed '%s'",
-				   bonobo_exception_get_text (my_ev));
+		if (BONOBO_EX (my_ev)) {
+			char *text;
+			
+			text = bonobo_exception_get_text (my_ev);
+			g_warning ("remove_listener failed '%s'", text);
+			g_free (text);
+		}
+		
 		CORBA_exception_free (&ev);
 	}
 }
@@ -432,9 +437,14 @@ bonobo_event_source_client_add_listener (Bonobo_Unknown object,
  add_listener_end:
 
 	if (!opt_ev) {
-		if (BONOBO_EX (my_ev))
-			g_warning ("add_listener failed '%s'",
-				   bonobo_exception_get_text (my_ev));
+		if (BONOBO_EX (my_ev)) {
+			char *text;
+			
+			text = bonobo_exception_get_text (my_ev);
+			g_warning ("add_listener failed '%s'", text);
+			g_free (text);
+		}
+		
 		CORBA_exception_free (&ev);
 	}
 
