@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * bonobo-moniker-simple: Simplified object naming abstraction
  *
  * Author:
@@ -18,7 +18,7 @@ BEGIN_GNOME_DECLS
 #define BONOBO_MONIKER_SIMPLE(o)          (GTK_CHECK_CAST ((o), BONOBO_MONIKER_SIMPLE_TYPE, BonoboMonikerSimple))
 #define BONOBO_MONIKER_SIMPLE_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), BONOBO_MONIKER_SIMPLE_TYPE, BonoboMonikerSimpleClass))
 #define BONOBO_IS_MONIKER_SIMPLE(o)       (GTK_CHECK_TYPE ((o), BONOBO_MONIKER_SIMPLE_TYPE))
-#define BONOBO_IS_MONIKER_SIMEPL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_MONIKER_SIMPLE_TYPE))
+#define BONOBO_IS_MONIKER_SIMPLE_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_MONIKER_SIMPLE_TYPE))
 
 typedef struct _BonoboMonikerSimple        BonoboMonikerSimple;
 typedef struct _BonoboMonikerSimplePrivate BonoboMonikerSimplePrivate;
