@@ -285,7 +285,7 @@ bonobo_moniker_util_qi_return (Bonobo_Unknown     object,
  release_unref_object:	
 	bonobo_object_release_unref (object, ev);
 
-	if (retval != CORBA_OBJECT_NIL)
+	if (retval != CORBA_OBJECT_NIL && !BONOBO_EX (ev))
 		return CORBA_Object_duplicate (retval, ev);
 	else
 		return CORBA_OBJECT_NIL;
@@ -678,7 +678,10 @@ async_activation_cb (CORBA_Object activated_object,
 				exceptions
 			};
 			CORBA_Object obj = CORBA_OBJECT_NIL;
-			gpointer arg_values [2] = { &obj, &ctx->name };
+			gpointer arg_values [2];
+
+			arg_values [0] = &obj;
+			arg_values [1] = &ctx->name;
 	
 			bonobo_async_invoke (&method, async_parse_cb, ctx,
 					     ctx->timeout_msec,
@@ -811,7 +814,7 @@ bonobo_moniker_resolve_async (Bonobo_Moniker         moniker,
 		arguments,
 		exceptions
 	};
-	gpointer arg_values [2] = { &options, &interface_name };
+	gpointer arg_values [2];
 	resolve_async_ctx_t *ctx;
 	
 	g_return_if_fail (ev != NULL);
@@ -820,6 +823,9 @@ bonobo_moniker_resolve_async (Bonobo_Moniker         moniker,
 	g_return_if_fail (options != CORBA_OBJECT_NIL);
 	g_return_if_fail (interface_name != CORBA_OBJECT_NIL);
 
+	arg_values [0] = &options;
+	arg_values [1] = &interface_name;
+
 	ctx = g_new0 (resolve_async_ctx_t, 1);
 	ctx->cb = cb;
 	ctx->user_data = user_data;
