@@ -52,8 +52,39 @@ struct _BonoboPlugPrivate {
 /* From Tk */
 #define EMBEDDED_APP_WANTS_FOCUS NotifyNormal+20
 
+/* Sometimes we have to forward keyboard events to our parent socket because
+ * they get received on the plug side when the plug does not have the focus, or
+ * because no widget within the plug handled the event and we must propagate it
+ * upwards.  However, since we are using XSendEvent(), we have to use the
+ * original keycode and state values for the synthetic event.  GDK translates
+ * these and we cannot recover them from a GTK+ widget keyboard handler.  So we
+ * install an event filter for all keyboard events, ignore those that are not
+ * for plug windows, and store the remaining ones in this table, which is a
+ * circular buffer.  The table is keyed by the timestamps of the events.  When
+ * we have to forward a key event, we fetch the original values from this table.
+ */
+#define KEY_EVENT_TABLE_SIZE 20
+
+struct KeyEvent {
+	guint32 time;
+	guint keycode;
+	guint state;
+};
+
+struct KeyEvent key_event_table[KEY_EVENT_TABLE_SIZE];
+
+/* The table is a circular buffer.  Events get inserted at the tail, get removed
+ * from the head.
+ */
+static int key_event_table_head;
+static int key_event_table_tail;
+static int key_event_table_nelements;
+
+
 static GtkWindowClass *parent_class = NULL;
 
+static void install_filter (GdkWindow *window);
+
 
 
 /**
@@ -145,6 +176,137 @@ bonobo_plug_unrealize (GtkWidget *widget)
 	}
 }
 
+/* Checks whether a window is a descendant of a plug window. */
+static gboolean
+is_descendant_window_of_plug (GdkWindow *window)
+{
+	while (window) {
+		GtkWidget *widget;
+
+		widget = window->user_data;
+		if (widget && BONOBO_IS_PLUG (widget))
+			return TRUE;
+
+		window = gdk_window_get_parent (window);
+	}
+
+	return FALSE;
+}
+
+/* Filter function for all events.  See the comments for key_event_table above.
+ * We filter key events and log them in the key_event_table, and we take care
+ * of child window creations.
+ */
+static GdkFilterReturn
+event_filter_cb (GdkXEvent *xevent, GdkEvent *event, gpointer data)
+{
+	XEvent *xev;
+	struct KeyEvent *ke;
+	GdkWindow *w;
+
+	xev = (XEvent *) xevent;
+
+	/* Ignore non-keyboard events */
+	if (!(xev->type == KeyPress || xev->type == KeyRelease || xev->type == CreateNotify))
+		return GDK_FILTER_CONTINUE;
+
+	if (!is_descendant_window_of_plug (gdk_window_lookup (xev->xany.window)))
+		return GDK_FILTER_CONTINUE;
+
+	switch (xev->type) {
+	case KeyPress:
+	case KeyRelease:
+		ke = key_event_table + key_event_table_tail;
+
+		ke->time = xev->xkey.time;
+		ke->keycode = xev->xkey.keycode;
+		ke->state = xev->xkey.state;
+
+		/* We just overwrite the oldest entries if the table becomes full */
+
+		if (key_event_table_tail == key_event_table_head) {
+			if (key_event_table_nelements == 0)
+				key_event_table_nelements = 1;
+			else {
+				g_assert (key_event_table_nelements == KEY_EVENT_TABLE_SIZE);
+
+				key_event_table_head++;
+				if (key_event_table_head == KEY_EVENT_TABLE_SIZE)
+					key_event_table_head = 0;
+			}
+
+			key_event_table_tail++;
+			if (key_event_table_tail == KEY_EVENT_TABLE_SIZE)
+				key_event_table_tail = 0;
+		} else {
+			key_event_table_tail++;
+			if (key_event_table_tail == KEY_EVENT_TABLE_SIZE)
+				key_event_table_tail = 0;
+
+			key_event_table_nelements++;
+			g_assert (key_event_table_nelements <= KEY_EVENT_TABLE_SIZE);
+		}
+
+		return GDK_FILTER_CONTINUE;
+
+	case CreateNotify:
+		w = gdk_window_lookup (xev->xcreatewindow.window);
+		if (w)
+			install_filter (w);
+
+		return GDK_FILTER_CONTINUE;
+
+	default:
+		g_assert_not_reached ();
+		return GDK_FILTER_CONTINUE;
+	}
+}
+
+/* Recursively sets up the key event filter for the specified window and all its
+ * children.
+ */
+static void
+install_filter (GdkWindow *window)
+{
+	GList *children;
+	GList *l;
+	Window xwindow;
+	XWindowAttributes attr;
+
+	gdk_window_add_filter (window, event_filter_cb, NULL);
+
+	/* Add SubstructureNotifyMask so that we can monitor for child window creations */
+
+	xwindow = GDK_WINDOW_XWINDOW (window);
+	if (XGetWindowAttributes (GDK_DISPLAY (), xwindow, &attr) == Success)
+		XSelectInput (GDK_DISPLAY (), xwindow, attr.your_event_mask | SubstructureNotifyMask);
+
+	/* Add filters for all the children */
+
+	children = gdk_window_get_children (window);
+
+	for (l = children; l; l = l->next) {
+		GdkWindow *w;
+
+		w = l->data;
+		install_filter (w);
+	}
+
+	g_list_free (children);
+}
+
+/* map handler for the plug widget.  We install the key event filter for all of
+ * our child windows here, ugh.
+ */
+static void
+bonobo_plug_map (GtkWidget *widget)
+{
+	if (GTK_WIDGET_CLASS (parent_class)->map)
+		(* GTK_WIDGET_CLASS (parent_class)->map) (widget);
+
+	install_filter (widget->window);
+}
+
 static void
 bonobo_plug_realize (GtkWidget *widget)
 {
@@ -209,29 +371,74 @@ bonobo_plug_realize (GtkWidget *widget)
 	gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
 }
 
+/* Looks up a KeyEvent structure in the key event table based on the timestamp
+ * of the specified event.  If it is not found, returns NULL.
+ */
+static struct KeyEvent *
+lookup_key_event (GdkEventKey *event)
+{
+	int i;
+
+	if (key_event_table_nelements == 0)
+		return NULL;
+
+	i = key_event_table_head;
+
+	while (key_event_table_nelements > 0) {
+		key_event_table_head++;
+		if (key_event_table_head == KEY_EVENT_TABLE_SIZE)
+			key_event_table_head = 0;
+
+		key_event_table_nelements--;
+
+		if (key_event_table[i].time == event->time)
+			return key_event_table + i;
+	}
+
+	return NULL;
+}
+
+/* Extracts a key event from the key event table and forwards it to our parent
+ * socket.
+ */
 static void
-bonobo_plug_forward_key_press (BonoboPlug *plug, GdkEventKey *event)
+bonobo_plug_forward_key_event (BonoboPlug *plug, GdkEventKey *event)
 {
 	BonoboPlugPrivate *priv;
 	XEvent xevent;
+	struct KeyEvent *ke;
 
 	priv = plug->priv;
 
-	xevent.xkey.type = KeyPress;
+	if (event->type == GDK_KEY_PRESS)
+		xevent.xkey.type = KeyPress;
+	else if (event->type == GDK_KEY_RELEASE)
+		xevent.xkey.type = KeyRelease;
+	else
+		g_assert_not_reached ();
+
 	xevent.xkey.display = GDK_WINDOW_XDISPLAY (GTK_WIDGET(plug)->window);
 	xevent.xkey.window = GDK_WINDOW_XWINDOW (priv->socket_window);
 	xevent.xkey.root = GDK_ROOT_WINDOW (); /* FIXME */
 	xevent.xkey.time = event->time;
-	/* FIXME, the following might cause big problems for non-GTK apps */
 	xevent.xkey.x = 0;
 	xevent.xkey.y = 0;
 	xevent.xkey.x_root = 0;
 	xevent.xkey.y_root = 0;
-	xevent.xkey.state = event->state;
-	xevent.xkey.keycode =  XKeysymToKeycode(GDK_DISPLAY(),
-						event->keyval);
 	xevent.xkey.same_screen = TRUE; /* FIXME ? */
 
+	ke = lookup_key_event (event);
+	if (ke) {
+		xevent.xkey.keycode = ke->keycode;
+		xevent.xkey.state = ke->state;
+	} else {
+		/* Do the best we can do at this point, even if we may lose
+		 * information from the original event.
+		 */
+		xevent.xkey.state = event->state;
+		xevent.xkey.keycode = XKeysymToKeycode(GDK_DISPLAY(), event->keyval);
+	}
+
 	gdk_error_trap_push ();
 	XSendEvent (gdk_display,
 		    GDK_WINDOW_XWINDOW (priv->socket_window),
@@ -240,7 +447,7 @@ bonobo_plug_forward_key_press (BonoboPlug *plug, GdkEventKey *event)
 	gdk_error_trap_pop ();
 }
 
-/* Key_press_event handle for the plug widget */
+/* Key_press_event handler for the plug widget */
 static gint
 bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 {
@@ -262,7 +469,7 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 	window = GTK_WINDOW (widget);
 
 	if (!GTK_WIDGET_HAS_FOCUS (widget)) {
-		bonobo_plug_forward_key_press (plug, event);
+		bonobo_plug_forward_key_event (plug, event);
 		return FALSE;
 	}
 
@@ -343,7 +550,7 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 				gdk_flush ();
 				gdk_error_trap_pop ();
 
-				bonobo_plug_forward_key_press (plug, event);
+				bonobo_plug_forward_key_event (plug, event);
 			}
 
 			return_val = TRUE;
@@ -355,7 +562,44 @@ bonobo_plug_key_press_event (GtkWidget *widget, GdkEventKey *event)
 	 * keybinding or something interesting.
 	 */
 	if (!return_val)
-		bonobo_plug_forward_key_press (plug, event);
+		bonobo_plug_forward_key_event (plug, event);
+
+	return return_val;
+}
+
+/* Key_release_event handler for the plug widget */
+static gint
+bonobo_plug_key_release_event (GtkWidget *widget, GdkEventKey *event)
+{
+	BonoboPlug *plug;
+	GtkWindow *window;
+	gint return_val;
+
+	g_return_val_if_fail (widget != NULL, FALSE);
+	g_return_val_if_fail (BONOBO_IS_PLUG (widget), FALSE);
+	g_return_val_if_fail (event != NULL, FALSE);
+
+	plug = BONOBO_PLUG (widget);
+
+	if (!GTK_WIDGET_HAS_FOCUS (widget)) {
+		bonobo_plug_forward_key_event (plug, event);
+		return FALSE;
+	}
+
+	window = GTK_WINDOW (widget);
+
+	return_val = FALSE;
+	if (window->focus_widget
+	    && window->focus_widget != widget
+	    && GTK_WIDGET_IS_SENSITIVE (window->focus_widget))
+		return_val = gtk_widget_event (window->focus_widget, (GdkEvent*) event);
+
+	/*
+	 * If we havn't handled it pass it on to our socket, since it might be a
+	 * keybinding or something interesting.
+	 */
+	if (!return_val)
+		bonobo_plug_forward_key_event (plug, event);
 
 	return return_val;
 }
@@ -484,7 +728,7 @@ bonobo_plug_set_focus (GtkWindow *window, GtkWidget *focus)
 	priv = plug->priv;
 
 	(* GTK_WINDOW_CLASS (parent_class)->set_focus) (window, focus);
-  
+
 	if (focus && GTK_WIDGET_CAN_FOCUS (focus) && !GTK_WIDGET_HAS_FOCUS (window)) {
 		XEvent xevent;
 
@@ -521,6 +765,18 @@ bonobo_plug_init (BonoboPlug *plug)
 	priv->has_focus = FALSE;
 }
 
+/* Sets up the key event filter and key event table; see the comments for
+ * key_event_table above.
+ */
+static void
+setup_event_filter (void)
+{
+	key_event_table_head = key_event_table_tail = key_event_table_nelements = 0;
+
+	/* This is a default event filter, so we pass NULL for the window field */
+	gdk_window_add_filter (NULL, event_filter_cb, NULL);
+}
+
 static void
 bonobo_plug_class_init (BonoboPlugClass *class)
 {
@@ -538,15 +794,19 @@ bonobo_plug_class_init (BonoboPlugClass *class)
 
 	object_class->destroy = bonobo_plug_destroy;
 
+	widget_class->map = bonobo_plug_map;
 	widget_class->realize = bonobo_plug_realize;
 	widget_class->unrealize = bonobo_plug_unrealize;
 	widget_class->key_press_event = bonobo_plug_key_press_event;
+	widget_class->key_release_event = bonobo_plug_key_release_event;
 	widget_class->focus_in_event = bonobo_plug_focus_in_event;
 	widget_class->focus_out_event = bonobo_plug_focus_out_event;
 
 	container_class->focus = bonobo_plug_focus;
 
 	window_class->set_focus = bonobo_plug_set_focus;
+
+	setup_event_filter ();
 }
 
 guint
@@ -577,7 +837,7 @@ bonobo_plug_get_type ()
  * bonobo_plug_set_control:
  * @plug: A plug.
  * @control: Control that wraps the plug widget.
- * 
+ *
  * Sets the #BonoboControl that the plug will use to proxy requests to the
  * parent container.
  **/
@@ -601,7 +861,7 @@ bonobo_plug_set_control (BonoboPlug *plug, BonoboControl *control)
 /**
  * bonobo_plug_clear_focus_chain:
  * @plug: A plug.
- * 
+ *
  * Clears the focus children from the container hierarchy inside a plug.  This
  * should be used only by the #BonoboControl implementation.
  **/
