@@ -56,6 +56,63 @@ widget_get_attr (GtkWidget *widget)
 				    WIDGET_ATTR_KEY);
 }
 
+static void
+set_values (BonoboUIConfigWidget *config)
+{
+	char    *txt;
+	BonoboUINode *node;
+	gboolean hidden = FALSE;
+	gboolean tooltips = TRUE;
+	BonoboUIToolbarStyle style;
+
+	g_return_if_fail (config->priv->cur_path != NULL);
+
+	node = bonobo_ui_engine_get_path (config->engine, config->priv->cur_path);
+
+	if ((txt = bonobo_ui_node_get_attr (node, "hidden"))) {
+		hidden = atoi (txt);
+		bonobo_ui_node_free_string (txt);
+	}
+
+	if (hidden)
+		gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (config->priv->hide),
+			TRUE);
+	else
+		gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (config->priv->show),
+			TRUE);
+	
+	/* Set the tooltips */
+	if ((txt = bonobo_ui_node_get_attr (node, "tips"))) {
+		tooltips = atoi (txt);
+		bonobo_ui_node_free_string (txt);
+	}
+	
+	gtk_toggle_button_set_active (
+		GTK_TOGGLE_BUTTON (config->priv->tooltips),
+		tooltips);
+
+	/* Set the look */
+	style = bonobo_ui_sync_toolbar_get_look (config->engine, node);
+	switch (style) {
+	case BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY:
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon), TRUE);
+		break;
+
+	case BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT:
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon_and_text), TRUE);
+		break;
+
+	case BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT:
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->priority_text), TRUE);
+		break;
+		
+	default:
+		break;
+	}
+}
+
 static void
 select_child_cb (GtkList	      *list,
 		 GtkWidget            *child,
@@ -71,34 +128,9 @@ select_child_cb (GtkList	      *list,
 	gtk_widget_set_sensitive (config->priv->left_attrs, node != NULL);
 	gtk_widget_set_sensitive (config->priv->right_attrs, node != NULL);
 
-	if (node) {
-		char    *txt;
-		gboolean hidden = FALSE;
-		gboolean tooltips = TRUE;
-
-		if ((txt = bonobo_ui_node_get_attr (node, "hidden"))) {
-			hidden = atoi (txt);
-			bonobo_ui_node_free_string (txt);
-		}
-
-		if (hidden)
-			gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (config->priv->hide),
-				TRUE);
-		else
-			gtk_toggle_button_set_active (
-				GTK_TOGGLE_BUTTON (config->priv->show),
-				TRUE);
-
-		if ((txt = bonobo_ui_node_get_attr (node, "tips"))) {
-			tooltips = atoi (txt);
-			bonobo_ui_node_free_string (txt);
-		}
-		
-		gtk_toggle_button_set_active (
-			GTK_TOGGLE_BUTTON (config->priv->tooltips),
-			tooltips);
-	} else
+	if (node)
+		set_values (config);
+	else
 		g_warning ("Toolbar has been removed");
 }
 
@@ -212,44 +244,6 @@ look_cb (GtkWidget            *button,
 		config->priv->cur_path, "look", value);
 }
 
-static void
-set_values (BonoboUIConfigWidget *config)
-{
-	BonoboUIToolbarStyle style;
-	BonoboUINode *node;
-	char *value;
-
-	g_return_if_fail (config->priv->cur_path != NULL);
-
-	node = bonobo_ui_engine_get_path (config->engine, config->priv->cur_path);
-
-	/* Set the look */
-	style = bonobo_ui_sync_toolbar_get_look (config->engine, node);
-	switch (style) {
-	case BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY:
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon), TRUE);
-		break;
-
-	case BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT:
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->icon_and_text), TRUE);
-		break;
-
-	case BONOBO_UI_TOOLBAR_STYLE_PRIORITY_TEXT:
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->priority_text), TRUE);
-		break;
-		
-	default:
-		break;
-	}
-	
-	/* Set the tooltips */
-	value = bonobo_ui_node_get_attr (node, "tips");
-	if (value != NULL) {
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (config->priv->tooltips), atoi (value));
-		bonobo_ui_node_free_string (value);
-	}
-}
-
 static void
 widgets_init (BonoboUIConfigWidget *config,
 	      GtkAccelGroup        *accel_group)
