@@ -521,7 +521,7 @@ dialog_new (BonoboUIEngineConfig *config)
 
 	accel_group = gtk_accel_group_new ();
 
-	window = gnome_dialog_new (_("Configure UI"), 
+	window = gnome_dialog_new (_("Customize Toolbars"),
 				   GNOME_STOCK_BUTTON_OK,
 				   NULL);
 	gnome_dialog_set_default (GNOME_DIALOG (window), 0);
