@@ -98,7 +98,6 @@ impl_bonobo_ui_sync_toolbar_state (BonoboUISync     *sync,
 	char *min_width;
 	char *behavior;
 	char **behavior_array;
-	GdkPixbuf *icon_pixbuf;
 	gboolean priority;
 
 	/* FIXME: to debug control problem */
@@ -128,14 +127,14 @@ impl_bonobo_ui_sync_toolbar_state (BonoboUISync     *sync,
 
 	bonobo_ui_toolbar_item_set_want_label (
 		BONOBO_UI_TOOLBAR_ITEM (widget), priority);
-
-	icon_pixbuf = cmd_get_toolbar_pixbuf (node, cmd_node);
-
+	
 	type  = bonobo_ui_engine_get_attr (node, cmd_node, "type");
 	label = bonobo_ui_engine_get_attr (node, cmd_node, "label");
 	
 	if (!type || !strcmp (type, "toggle")) {
-
+		GdkPixbuf *icon_pixbuf;
+		
+		icon_pixbuf = cmd_get_toolbar_pixbuf (node, cmd_node);
 		if (icon_pixbuf) {
 			bonobo_ui_toolbar_button_item_set_icon (
 				BONOBO_UI_TOOLBAR_BUTTON_ITEM (widget), icon_pixbuf);
@@ -144,11 +143,18 @@ impl_bonobo_ui_sync_toolbar_state (BonoboUISync     *sync,
 
 		if (label) {
 			gboolean err;
-			char *txt = bonobo_ui_util_decode_str (label, &err);
+			
+			txt = bonobo_ui_util_decode_str (label, &err);
+			
 			if (err) {
 				g_warning ("Encoding error in label on '%s', you probably forgot to "
 					   "put an '_' before label in your xml file",
-					   bonobo_ui_xml_make_path (node));
+					   (txt = bonobo_ui_xml_make_path (node)));
+				
+				bonobo_ui_node_free_string (type);
+				bonobo_ui_node_free_string (label);
+				g_free (txt);
+				
 				return;
 			}
 
