@@ -162,6 +162,7 @@ item_destroy_cb (GtkObject *object,
 
 	widget = GTK_WIDGET (object);
 	priv->items = g_list_remove (priv->items, object);
+	gtk_object_unref (object);
 }
 
 static void
@@ -319,6 +320,7 @@ show_popup_window (BonoboUIToolbar *toolbar)
 {
 	BonoboUIToolbarPrivate *priv;
 	const GtkAllocation *toolbar_allocation;
+	GtkRequisition requisition;
 	int x, y;
 
 	priv = toolbar->priv;
@@ -331,10 +333,20 @@ show_popup_window (BonoboUIToolbar *toolbar)
 
 	toolbar_allocation = & GTK_WIDGET (toolbar)->allocation;
 
-	if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+	gtk_widget_size_request (priv->popup_window, &requisition);
+
+	if (priv->orientation == GTK_ORIENTATION_HORIZONTAL) {
 		x += toolbar_allocation->x + toolbar_allocation->width;
-	else
+		if (x >= gdk_screen_width () - requisition.width)
+			y += toolbar_allocation->height;
+	} else {
 		y += toolbar_allocation->y + toolbar_allocation->height;
+		if (y >= gdk_screen_height () - requisition.height)
+			x += toolbar_allocation->width;
+	}
+
+	x = CLAMP (x, 0, MAX (0, gdk_screen_width () - requisition.width));
+	y = CLAMP (y, 0, MAX (0, gdk_screen_height () - requisition.height));
 
 	gtk_widget_set_uposition (GTK_WIDGET (priv->popup_window), x, y);
 
@@ -1229,6 +1241,7 @@ bonobo_ui_toolbar_construct (BonoboUIToolbar *toolbar)
 
 	frame = gtk_frame_new (NULL);
 	gtk_widget_show (frame);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 	gtk_container_add (GTK_CONTAINER (priv->popup_window), frame);
 
 	priv->popup_window_vbox = gtk_vbox_new (FALSE, 0);
@@ -1326,8 +1339,11 @@ bonobo_ui_toolbar_insert (BonoboUIToolbar *toolbar,
 	 * a widget and then re-added it to the toolbar at a later
 	 * date, and un-parenting doesn't work quite properly yet.
 	 */
-	if (!g_list_find (priv->items, item))
+	if (!g_list_find (priv->items, item)) {
+		gtk_object_ref (GTK_OBJECT (item));
+		gtk_object_sink (GTK_OBJECT (item));
 		priv->items = g_list_insert (priv->items, item, position);
+	}
 
 	gtk_signal_connect_while_alive (GTK_OBJECT (item), "destroy",
 					GTK_SIGNAL_FUNC (item_destroy_cb), toolbar,
@@ -1339,12 +1355,18 @@ bonobo_ui_toolbar_insert (BonoboUIToolbar *toolbar,
 					GTK_SIGNAL_FUNC (item_set_want_label_cb), toolbar,
 					GTK_OBJECT (toolbar));
 
+	gtk_object_ref (GTK_OBJECT (toolbar));
+	gtk_object_ref (GTK_OBJECT (item));
+
 	set_attributes_on_child (item, priv->orientation, priv->style);
 	parentize_widget (toolbar, GTK_WIDGET (item));
 
 	g_assert (GTK_WIDGET (item)->parent == GTK_WIDGET (toolbar));
 
 	gtk_widget_queue_resize (GTK_WIDGET (toolbar));
+
+	gtk_object_unref (GTK_OBJECT (item));
+	gtk_object_unref (GTK_OBJECT (toolbar));
 }
 
 GList *
