@@ -480,7 +480,6 @@ bonobo_ui_util_xml_get_icon_pixbuf (BonoboUINode *node, gboolean prepend_menu)
 		/* Get pointer to GdkPixbuf */
 		icon_pixbuf = bonobo_ui_util_xml_to_pixbuf (text);
 
-		g_return_val_if_fail (icon_pixbuf != NULL, NULL);
 	} else
 		g_warning ("Unknown icon_pixbuf type '%s'", type);
 
@@ -490,8 +489,9 @@ bonobo_ui_util_xml_get_icon_pixbuf (BonoboUINode *node, gboolean prepend_menu)
 	if (icon_pixbuf) {
 		gdk_pixbuf_ref (icon_pixbuf);
 		g_hash_table_insert (pixbuf_cache, key, icon_pixbuf);
-	}
-
+	} else
+		g_free (key);
+	
 	return icon_pixbuf;
 }
 
@@ -643,9 +643,12 @@ bonobo_help_file_find_file (const char *datadir, const char *app,
 	
 	while (!res && language_list) {
 		const gchar *lang;
-		
+
 		lang = language_list->data;
 		
+		if (!lang)
+			continue;
+
 		buf = g_string_new (NULL);
 		g_string_sprintf (buf, "%s/gnome/help/%s/%s/%s",
 				  datadir, app, lang, path);
