@@ -13,22 +13,25 @@
 #include <bonobo.h>
 
 typedef struct {
-	BonoboUIHandler  *uih;
-	GtkWidget	*app;
-	GtkWidget	*vbox;
-	BonoboViewFrame *active_view_frame;
-	GList           *view_list;
+	BonoboUIContainer	*container;
+	BonoboUIComponent	*component;
+	BonoboWindow		*win;
+	GtkWidget		*vbox;
+	BonoboViewFrame		*active_view_frame;
+	GList			*view_list;
 } Frame;
 
 typedef struct {
-	BonoboClientSite   *client_site;
-	BonoboObjectClient *server;
-	gchar *name;
-	gint menu_id;
+	BonoboClientSite	*client_site;
+	BonoboObjectClient	*server;
+	BonoboZoomableFrame	*zoomable_frame;
+	gchar			*verb;
+	gchar			*name;
+	gint			 verb_id;
 } Buffer;
 
 typedef struct {
-	BonoboContainer  *container;
+	BonoboItemContainer *container;
 	GList *frame_list;
 	GList *buffer_list;
 	GtkFileSelection *fs;
@@ -36,19 +39,12 @@ typedef struct {
 
 extern Application app;
 
-void file_menu_kill_cb          (BonoboUIHandler *uih, void *data, char *path);
-void view_menu_new_window_cb    (BonoboUIHandler *uih, void *data, char *path);
-void view_menu_delete_window_cb (BonoboUIHandler *uih, void *data, char *path);
-void view_menu_split_window_cb  (BonoboUIHandler *uih, void *data, char *path);
-void view_menu_one_window_cb    (BonoboUIHandler *uih, void *data, char *path);
-void file_menu_exit_cb          (BonoboUIHandler *uih, void *data, char *path);
-void edit_menu_preferences_cb   (BonoboUIHandler *uih, void *data, char *path);
-void help_menu_about_cb         (BonoboUIHandler *uih, void *data, char *path);
-void help_menu_help_gnome_cb    (BonoboUIHandler *uih, void *data, char *path);
+extern BonoboUIVerb gshell_verbs[];
 
 Frame          *get_active_frame           (GtkWidget *widget);
 BonoboViewFrame *get_active_view_frame      (Frame *frame);
 Buffer         *buffer_create              (const char *component_goad_id);
+Buffer         *buffer_create_for_control  (const char *component_goad_id);
 gint            view_remove                (Frame *frame, 
 					    BonoboViewFrame *view_frame);
 void            buffer_add_view            (Buffer *buffer, 
@@ -56,7 +52,7 @@ void            buffer_add_view            (Buffer *buffer,
 					    gint pos);
 gboolean        bonobo_object_has_interface (BonoboObject *obj, 
 					    char *interface);
-void            set_buffer_cb              (BonoboUIHandler *uih, 
+void            set_buffer_cb              (BonoboUIComponent *uih, 
 					    void *buffer,  
 					    const char *path);
 
