@@ -402,8 +402,8 @@ efs_file_read (EFSFile *file, gpointer buf, gint32 count, guint32 *bytes_read)
 			if (s->err == Z_STREAM_END) {
 				/* Check CRC */
 				s->crc = crc32(s->crc, start, (uInt)
-					       ((gpointer)s->stream.next_out -
-						start));
+					       ((guchar *) s->stream.next_out -
+						(guchar *) start));
 				start = s->stream.next_out;
 
 				if (gzstream_get_long(file) != s->crc)
@@ -412,7 +412,7 @@ efs_file_read (EFSFile *file, gpointer buf, gint32 count, guint32 *bytes_read)
 			if (s->err != Z_OK || s->eof) break;
 		}
 		s->crc = crc32(s->crc, start, (uInt)
-			       ((gpointer)s->stream.next_out - start));
+			       ((guchar *) s->stream.next_out - (guchar *) start));
 
 		*bytes_read = count - s->stream.avail_out;
 		
